/*
    SPDX-FileCopyrightText: 2024 Aleix Pol i Gonzalez <aleixpol@kde.org>
    SPDX-FileCopyrightText: 2025 Devin Lin <devin@kde.org>

    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
*/

#pragma once

#include <QQuickItem>
#include <QQuickWindow>
#include <QVirtualKeyboardInputEngine>

#include "inputplugin.h"

class InputListenerItem : public QQuickItem
{
    Q_OBJECT
    // QML_ELEMENT
    Q_PROPERTY(QVirtualKeyboardInputEngine *engine WRITE setEngine)
    Q_PROPERTY(bool keyboardNavigationActive WRITE setKeyboardNavigationActive)

public:
    InputListenerItem();

    void setEngine(QVirtualKeyboardInputEngine *engine);
    void setKeyboardNavigationActive(bool keyboardNavigationActive);

    QVariant inputMethodQuery(Qt::InputMethodQuery query) const override;

    void keyPressEvent(QKeyEvent *event) override;
    void keyReleaseEvent(QKeyEvent *event) override;
    void inputMethodEvent(QInputMethodEvent *event) override;

Q_SIGNALS:
    void keyNavigationPressed(int key);
    void keyNavigationReleased(int key);

private:
    InputPlugin m_input;
    bool m_keyboardNavigationActive = false;
};
